twall.web package
=================

This package contains the web version of the application that runs on Flask. It displays a simple search bar for the
user to enter his or her query. Once a query is submitted, it displays the loaded tweets on a single page. Unlike the
console version, the web application enriches the tweet text to include hashtags, mentions, links and images.

Module contents
---------------

.. automodule:: twall.web
    :members:
    :undoc-members:
    :show-inheritance:
